@@ -3,4 +3,4 @@
 # Author: Goddy <goddy@mykg.ai> 2021/9/16
 # Desc:
 
-from app import say_hi
+from goddy.app import say_hi
